@@ -20,15 +20,13 @@ class login:
         fin=hashlib.sha256(fi)
         finger=fin.hexdigest()
         print(text+finger)
-    def auth(auth):
-        if auth=='':
+    def auth(auth_id):
+        if auth_id=='':
             print('Please Enter auth_id')
             sys.exit()
         else:
             global auth_id
             global r
-            au=auth.encode('utf-8')
-            auth_id=str(base64.b64decode(au))
             r=requests.get('https://pastebin.com/raw/'+auth_id)
     def verify(mail, username, password):
         if username=='' and password=='' or username=='' or password=='' or mail=='':
